# Lifetimes API

::: wd.di.lifetimes.ServiceLifetime
    handler: python
    options:
      show_root_heading: true
      show_source: false
      show_bases: false # For enums, often cleaner not to show Enum base
      show_docstring_attributes: true # Show docstrings for enum members if any
      members_order: source # Enums often best in source order

